// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#ifndef ECM_QLOGGINGCATEGORY_KJOURNALDLIB_GENERAL_KJOURNALDLIB_LOG_GENERAL_H
#define ECM_QLOGGINGCATEGORY_KJOURNALDLIB_GENERAL_KJOURNALDLIB_LOG_GENERAL_H

#include <QLoggingCategory>

Q_DECLARE_LOGGING_CATEGORY(KJOURNALDLIB_GENERAL)


#endif
